store

package
v0.1.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 1, 2026 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Overview

Package store exposes application-facing persistence entrypoints.

It provides a thin, stable façade for constructing Datly-backed persistence services used by the runtime.

Index

Constants

const (
	DirectionBefore = old.DirectionBefore
	DirectionAfter  = old.DirectionAfter
	DirectionLatest = old.DirectionLatest
)

Variables

var ErrPermissionDenied = old.ErrPermissionDenied

Functions

func NewDatly

func NewDatly(ctx context.Context) (*datly.Service, error)

func NewDatlyFromWorkspace

func NewDatlyFromWorkspace(ctx context.Context, root string) (*datly.Service, error)

func NewDatlyInMemory

func NewDatlyInMemory(ctx context.Context) (*datly.Service, error)

func NewDatlyServiceFromEnv

func NewDatlyServiceFromEnv(ctx context.Context) (*datly.Service, error)

Types

type ConversationPage

type ConversationPage = old.ConversationPage

type Direction

type Direction = old.Direction

type MessagePage

type MessagePage = old.MessagePage

type Option

type Option = old.Option

func WithAdminPrincipal

func WithAdminPrincipal(userID string) Option

func WithPrincipal

func WithPrincipal(userID string) Option

func WithQuerySelector

func WithQuerySelector(selectors ...*hstate.NamedQuerySelector) Option

type PageInput

type PageInput = old.PageInput

type RunStepPage

type RunStepPage = old.RunStepPage

type Service

type Service = old.Service

func NewService

func NewService(dao *datly.Service) Service

func NewThinServiceFromEnv

func NewThinServiceFromEnv(ctx context.Context) (Service, error)

func NewThinServiceInMemory

func NewThinServiceInMemory(ctx context.Context) (Service, error)

type TurnPage

type TurnPage = old.TurnPage

Directories

Path Synopsis
Package conversation contains conversation-domain contracts and helpers.
Package conversation contains conversation-domain contracts and helpers.
cancel
Package cancel provides conversation/turn cancellation registries.
Package cancel provides conversation/turn cancellation registries.
Package data provides Datly-backed read/write persistence services.
Package data provides Datly-backed read/write persistence services.
memory
Package memory provides an in-memory conversation client implementation.
Package memory provides an in-memory conversation client implementation.
Package toolapprovalqueue contains mutable types for user personal tool approval queue rows.
Package toolapprovalqueue contains mutable types for user personal tool approval queue rows.
Package turnqueue contains mutable types for conversation turn queue rows.
Package turnqueue contains mutable types for conversation turn queue rows.

Jump to