Documentation
¶
Overview ¶
Package store exposes application-facing persistence entrypoints.
It provides a thin, stable façade for constructing Datly-backed persistence services used by the runtime.
Index ¶
- Constants
- Variables
- func NewDatly(ctx context.Context) (*datly.Service, error)
- func NewDatlyFromWorkspace(ctx context.Context, root string) (*datly.Service, error)
- func NewDatlyInMemory(ctx context.Context) (*datly.Service, error)
- func NewDatlyServiceFromEnv(ctx context.Context) (*datly.Service, error)
- type ConversationPage
- type Direction
- type MessagePage
- type Option
- type PageInput
- type RunStepPage
- type Service
- type TurnPage
Constants ¶
const ( DirectionBefore = old.DirectionBefore DirectionAfter = old.DirectionAfter DirectionLatest = old.DirectionLatest )
Variables ¶
var ErrPermissionDenied = old.ErrPermissionDenied
Functions ¶
func NewDatlyFromWorkspace ¶
Types ¶
type ConversationPage ¶
type ConversationPage = old.ConversationPage
type MessagePage ¶
type MessagePage = old.MessagePage
type Option ¶
func WithAdminPrincipal ¶
func WithPrincipal ¶
func WithQuerySelector ¶
func WithQuerySelector(selectors ...*hstate.NamedQuerySelector) Option
type RunStepPage ¶
type RunStepPage = old.RunStepPage
type Service ¶
func NewService ¶
Directories
¶
| Path | Synopsis |
|---|---|
|
Package conversation contains conversation-domain contracts and helpers.
|
Package conversation contains conversation-domain contracts and helpers. |
|
cancel
Package cancel provides conversation/turn cancellation registries.
|
Package cancel provides conversation/turn cancellation registries. |
|
Package data provides Datly-backed read/write persistence services.
|
Package data provides Datly-backed read/write persistence services. |
|
memory
Package memory provides an in-memory conversation client implementation.
|
Package memory provides an in-memory conversation client implementation. |
|
Package toolapprovalqueue contains mutable types for user personal tool approval queue rows.
|
Package toolapprovalqueue contains mutable types for user personal tool approval queue rows. |
|
Package turnqueue contains mutable types for conversation turn queue rows.
|
Package turnqueue contains mutable types for conversation turn queue rows. |
Click to show internal directories.
Click to hide internal directories.